Draws the permutation distribution of the studentized statistic with the
observed value marked. The subtitle reports the same Monte Carlo p-value
as perm_solomon().
Draws the permutation distribution of the studentized statistic with the
observed value marked. The subtitle reports the same Monte Carlo p-value
as perm_solomon().